@@ -20,7 +20,7 @@ def _from_mysql_call(args, **kwargs):
     parser.add_argument('-P', '--port', dest='port', default='')
     parser.add_argument('db_name', nargs='?', default='')
 
-    args = parser.parse_args(args)
+    args, _unused_args = parser.parse_known_args(args)
 
     db_name = first([args.name, args.db_name], default='')
     db_dict = {
@@ -47,7 +47,7 @@ def _from_psql_call(args, password='', **kwargs):
     parser.add_argument('-U', '--username', dest='user', default='')
     parser.add_argument('db_name', nargs='?', default='')
 
-    args = parser.parse_args(args)
+    args, _unused_args = parser.parse_known_args(args)
 
     db_name = first([args.name, args.db_name], default='')
     db_dict = {
